@@ -34,12 +34,214 @@ result_lock = threading.Lock()
 result = []
 
 
+# 同步公司基本信息
+
+def sync_company_base_info(symbol_list):
+    global result
+    result = []
+    create_index()
+    east_money_stock_info = get_east_money_stock_info()
+    east_money_stock_info = east_money_stock_info.sort_values(by=['list_date'], ascending=False)
+
+    de_listed_stock_list = company_common_service_api.get_de_list_company()
+    east_money_stock_info = east_money_stock_info.loc[~(
+        east_money_stock_info['symbol'].isin(de_listed_stock_list))]
+    east_money_stock_info = common_service_fun_api.exclude_ts_symbol(east_money_stock_info)
+    east_money_stock_info = east_money_stock_info.loc[~((east_money_stock_info['industry'] == '-')
+                                                        & (east_money_stock_info['now_price'] == 0))]
+
+    east_money_stock_info = common_service_fun_api.total_mv_classification(east_money_stock_info)
+    east_money_stock_info = common_service_fun_api.classify_symbol(east_money_stock_info)
+
+    # 将日期数值转换为日期时间格式
+    east_money_stock_info['list_date_01'] = pd.to_datetime(east_money_stock_info['list_date'], format='%Y%m%d')
+
+    # 开盘啦实时数据
+    kpl_real_time_quotes = kpl_real_time_quotes_api.get_kpl_real_time_quotes()
+
+    if symbol_list is not None:
+        east_money_stock_info = east_money_stock_info.loc[east_money_stock_info['symbol'].isin(symbol_list)]
+    count = east_money_stock_info.shape[0]
+    page_number = round(count / MAX_PAGE_NUMBER, 0) + 1
+    page_number = int(page_number)
+    threads = []
+
+    exist_company_df = mongodb_util.find_all_data(db_name_constant.COMPANY_INFO)
+
+    # 创建多个线程来获取数据
+    for page in range(page_number):  # 0到100页
+        end_count = (page + 1) * MAX_PAGE_NUMBER
+        begin_count = page * MAX_PAGE_NUMBER
+        page_df = east_money_stock_info.iloc[begin_count:end_count]
+        thread = threading.Thread(target=single_thread_sync_company_info,
+                                  args=(page_df, kpl_real_time_quotes, exist_company_df))
+        threads.append(thread)
+        thread.start()
+
+    # 等待所有线程完成
+    for thread in threads:
+        thread.join()
+
+    fail_df = east_money_stock_info.loc[east_money_stock_info['symbol'].isin(result)]
+    single_thread_sync_company_info(fail_df, kpl_real_time_quotes, exist_company_df)
+
+
+def get_east_money_stock_info():
+    all_real_time_quotes = em_stock_info_api.get_a_stock_info()
+    all_real_time_quotes = all_real_time_quotes[['symbol',
+                                                 'name',
+                                                 "now_price",
+                                                 'total_mv',
+                                                 'flow_mv',
+                                                 'pe_ttm',
+                                                 'sz_sh',
+                                                 'area',
+                                                 'pb',
+                                                 'list_date',
+                                                 'ROE',
+                                                 'total_share',
+                                                 'flow_share',
+                                                 'industry',
+                                                 'amount',
+                                                 "hk_stock_code",
+                                                 "hk_stock_name",
+                                                 'concept']]
+
+    return all_real_time_quotes
+
+
+def single_thread_sync_company_info(east_money_stock_info,
+                                    kpl_real_time_quotes, exist_company_df):
+    global result
+    fail_list = []
+    for company_one in east_money_stock_info.itertuples():
+        try:
+            # 同步公司控股子公司信息 异步执行
+            sync_company_hold_info_api.sync_company_hold_info(company_one.symbol)
+
+            company_info_type = ths_company_info_web.get_company_info_detail(company_one.symbol)
+            company_info_type = set_kzz_debt(company_info_type, company_one.symbol)
+            company_info_type['first_industry_code'] = company_info_type['hycode'].apply(
+                lambda x: x[1:3] + '0000')
+            company_info_type['second_industry_code'] = company_info_type['hy2code'].apply(
+                lambda x: x[1:5] + '00')
+            company_info_type['third_industry_code'] = company_info_type['hy3code'].apply(
+                lambda x: x[1:7])
+            # company_info_type['main_business_list'] = company_info_type['main_business_list']
+            # company_info_type['most_profitable_business'] = company_info_type['most_profitable_business']
+            # company_info_type['most_profitable_business_rate'] = company_info_type['most_profitable_business_rate']
+            # company_info_type['most_profitable_business_profit'] = company_info_type['most_profitable_business_profit']
+            #
+            company_info_type['first_sw_industry'] = company_info_type['hy']
+            company_info_type['second_sw_industry'] = company_info_type['hy2']
+            company_info_type['third_sw_industry'] = company_info_type['hy3']
+            # 保存申万行业信息
+            save_sw_data(company_info_type)
+
+            company_info_type['_id'] = company_one.symbol
+
+            company_info_type['name'] = company_one.name
+
+            company_info_type['em_industry'] = company_one.industry
+            company_info_type['em_concept'] = company_one.concept
+
+            company_info_type['hk_stock_code'] = company_one.hk_stock_code
+            company_info_type['hk_stock_name'] = company_one.hk_stock_name
+
+            company_info_type['now_price'] = company_one.now_price
+            company_info_type['total_share'] = company_one.total_share
+            company_info_type['flow_share'] = company_one.flow_share
+            company_info_type['total_mv'] = company_one.total_mv
+            company_info_type['flow_mv'] = company_one.flow_mv
+            company_info_type['area'] = company_one.area
+            company_info_type['list_date'] = company_one.list_date
+            now_date = datetime.now()
+            # 计算日期差值 距离现在上市时间
+            company_info_type['diff_days'] = (now_date - company_one.list_date_01).days
+
+            company_info_type['pe_ttm'] = company_one.pe_ttm
+            company_info_type['pb'] = company_one.pb
+            company_info_type['ROE'] = company_one.ROE
+            company_info_type['flow_mv_sp'] = company_one.flow_mv_sp
+            company_info_type['total_mv_sp'] = company_one.total_mv_sp
+            company_info_type['flow_mv_level'] = company_one.flow_mv_level
+            company_info_type['classification'] = company_one.classification
+
+            now_date = datetime.now()
+            str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
+
+            now_str_day = now_date.strftime('%Y-%m-%d')
+            company_info_type['sync_date'] = str_now_date
+
+            result_dict = calculate_circulation_ratio(company_one.symbol, now_str_day)
+
+            company_info_type['mv_circulation_ratio'] = result_dict['mv_circulation_ratio']
+            company_info_type['qfii_type'] = result_dict['qfii_type']
+            company_info_type['qfii_number'] = result_dict['qfii_number']
+            company_info_type['share_holder_sync_day'] = result_dict['share_holder_sync_day']
+
+            # 获取同花顺最新概念
+            company_info_type = ths_concept_common_service_api.set_ths_concept(company_one.symbol, company_info_type)
+
+            fix_symbol_industry_df = company_constant_data.get_fix_symbol_industry()
+            if company_one.symbol in list(fix_symbol_industry_df['symbol']):
+                # fix sw_industry
+                company_info_type = company_constant_data.fix_symbol_industry(company_info_type, company_one.symbol)
+
+            # todo fix industry
+            company_info_type['industry'] = company_info_type['second_sw_industry']
+            company_info_type['amount'] = company_one.amount
+
+            company_info_type['kpl_plate_list_info'] = '-'
+            company_info_type['kpl_plate_name'] = '-'
+            company_info_type['kpl_most_relative_name'] = '-'
+            now_date = datetime.now()
+            str_day = now_date.strftime('%Y-%m-%d')
+            deal_days = k_line_common_service_api.get_deal_days(str_day, company_one.symbol)
+            company_info_type['deal_days'] = deal_days
+
+            # 设置年报信息
+            company_info_type = get_recent_year_income(company_one.symbol, company_info_type, exist_company_df)
+
+            try:
+                if data_frame_util.is_not_empty(kpl_real_time_quotes):
+                    kpl_real_time_quotes_one = kpl_real_time_quotes.loc[
+                        kpl_real_time_quotes['symbol'] == company_one.symbol]
+
+                    if data_frame_util.is_not_empty(kpl_real_time_quotes_one):
+                        company_info_type['kpl_plate_name'] = list(kpl_real_time_quotes_one['plate_name_list'])[0]
+                        company_info_type['kpl_most_relative_name'] = \
+                            list(kpl_real_time_quotes_one['most_relative_name'])[
+                                0]
+                    company_info_type = set_kpl_data(kpl_real_time_quotes_one, company_info_type, company_one)
+
+                if bool(1 - ("kpl_plate_name" in company_info_type.columns)) or bool(
+                        1 - ("kpl_most_relative_name" in company_info_type.columns)):
+                    company_info_type['kpl_plate_name'] = ""
+                    company_info_type['kpl_most_relative_name'] = ""
+            except BaseException as e:
+                logger.warning("设置开盘啦数据异常:{},{}", company_one.symbol, e)
+
+            company_info_type = company_constant_data.filed_sort(company_info_type)
+            mongodb_util.save_mongo(company_info_type.copy(), 'company_info_base')
+            logger.info("同步公司信息完成:{}", company_one.symbol + '-' + company_one.name)
+        except BaseException as e:
+            fail_list.append(company_one.symbol)
+            logger.error("同步公司信息发生异常:{},{}", company_one.symbol, e)
+    with result_lock:
+        # 使用锁来保护 result 变量的访问，将每页的数据添加到结果中
+        result = fail_list
+
+
 # 计算实际流通比例
-def calculate_circulation_ratio(symbol):
+def calculate_circulation_ratio(symbol, now_str_day):
     query = {"symbol": symbol}
     stock_gdfx_free_top_1 = mongodb_util.descend_query(query, 'stock_gdfx_free_top_10', "period", 1)
     if stock_gdfx_free_top_1.shape[0] == 0:
         mv_circulation_ratio = 1
+        qfii_number = 0
+        qfii_type = 'A股'
+        share_holder_sync_day = now_str_day
     else:
         period_time = list(stock_gdfx_free_top_1['period'])[0]
 
@@ -125,30 +327,6 @@ def set_qfii_type(qfii_number, stock_free_qfii):
         return 0
 
 
-def get_east_money_stock_info():
-    all_real_time_quotes = em_stock_info_api.get_a_stock_info()
-    all_real_time_quotes = all_real_time_quotes[['symbol',
-                                                 'name',
-                                                 "now_price",
-                                                 'total_mv',
-                                                 'flow_mv',
-                                                 'pe_ttm',
-                                                 'sz_sh',
-                                                 'area',
-                                                 'pb',
-                                                 'list_date',
-                                                 'ROE',
-                                                 'total_share',
-                                                 'flow_share',
-                                                 'industry',
-                                                 'amount',
-                                                 "hk_stock_code",
-                                                 "hk_stock_name",
-                                                 'concept']]
-
-    return all_real_time_quotes
-
-
 def create_index():
     mongodb_util.create_index('company_info',
                               [("classification", 1)])
@@ -162,174 +340,6 @@ def create_index():
                               [("symbol", 1)])
 
 
-# 同步公司基本信息
-
-def sync_company_base_info(symbol_list):
-    global result
-    result = []
-    create_index()
-    east_money_stock_info = get_east_money_stock_info()
-    de_listed_stock_list = company_common_service_api.get_de_list_company()
-    east_money_stock_info = east_money_stock_info.loc[~(
-        east_money_stock_info['symbol'].isin(de_listed_stock_list))]
-    east_money_stock_info = common_service_fun_api.exclude_ts_symbol(east_money_stock_info)
-    east_money_stock_info = east_money_stock_info.loc[~((east_money_stock_info['industry'] == '-')
-                                                        & (east_money_stock_info['now_price'] == 0))]
-
-    east_money_stock_info = common_service_fun_api.total_mv_classification(east_money_stock_info)
-    east_money_stock_info = common_service_fun_api.classify_symbol(east_money_stock_info)
-
-    # 将日期数值转换为日期时间格式
-    east_money_stock_info['list_date_01'] = pd.to_datetime(east_money_stock_info['list_date'], format='%Y%m%d')
-
-    # 开盘啦实时数据
-    kpl_real_time_quotes = kpl_real_time_quotes_api.get_kpl_real_time_quotes()
-
-    if symbol_list is not None:
-        east_money_stock_info = east_money_stock_info.loc[east_money_stock_info['symbol'].isin(symbol_list)]
-    count = east_money_stock_info.shape[0]
-    page_number = round(count / MAX_PAGE_NUMBER, 0) + 1
-    page_number = int(page_number)
-    threads = []
-
-    exist_company_df = mongodb_util.find_all_data(db_name_constant.COMPANY_INFO)
-
-    # 创建多个线程来获取数据
-    for page in range(page_number):  # 0到100页
-        end_count = (page + 1) * MAX_PAGE_NUMBER
-        begin_count = page * MAX_PAGE_NUMBER
-        page_df = east_money_stock_info.iloc[begin_count:end_count]
-        thread = threading.Thread(target=single_thread_sync_company_info,
-                                  args=(page_df, kpl_real_time_quotes, exist_company_df))
-        threads.append(thread)
-        thread.start()
-
-    # 等待所有线程完成
-    for thread in threads:
-        thread.join()
-
-    fail_df = east_money_stock_info.loc[east_money_stock_info['symbol'].isin(result)]
-    single_thread_sync_company_info(fail_df, kpl_real_time_quotes, exist_company_df)
-
-
-def single_thread_sync_company_info(east_money_stock_info,
-                                    kpl_real_time_quotes, exist_company_df):
-    global result
-    fail_list = []
-    for company_one in east_money_stock_info.itertuples():
-        try:
-            # 同步公司控股子公司信息 异步执行
-            sync_company_hold_info_api.sync_company_hold_info(company_one.symbol)
-
-            company_info_type = ths_company_info_web.get_company_info_detail(company_one.symbol)
-            company_info_type = set_kzz_debt(company_info_type, company_one.symbol)
-            company_info_type['first_industry_code'] = company_info_type['hycode'].apply(
-                lambda x: x[1:3] + '0000')
-            company_info_type['second_industry_code'] = company_info_type['hy2code'].apply(
-                lambda x: x[1:5] + '00')
-            company_info_type['third_industry_code'] = company_info_type['hy3code'].apply(
-                lambda x: x[1:7])
-            # company_info_type['main_business_list'] = company_info_type['main_business_list']
-            # company_info_type['most_profitable_business'] = company_info_type['most_profitable_business']
-            # company_info_type['most_profitable_business_rate'] = company_info_type['most_profitable_business_rate']
-            # company_info_type['most_profitable_business_profit'] = company_info_type['most_profitable_business_profit']
-            #
-            company_info_type['first_sw_industry'] = company_info_type['hy']
-            company_info_type['second_sw_industry'] = company_info_type['hy2']
-            company_info_type['third_sw_industry'] = company_info_type['hy3']
-            # 保存申万行业信息
-            save_sw_data(company_info_type)
-
-            company_info_type['_id'] = company_one.symbol
-
-            company_info_type['name'] = company_one.name
-
-            company_info_type['em_industry'] = company_one.industry
-            company_info_type['em_concept'] = company_one.concept
-
-            company_info_type['hk_stock_code'] = company_one.hk_stock_code
-            company_info_type['hk_stock_name'] = company_one.hk_stock_name
-
-            company_info_type['now_price'] = company_one.now_price
-            company_info_type['total_share'] = company_one.total_share
-            company_info_type['flow_share'] = company_one.flow_share
-            company_info_type['total_mv'] = company_one.total_mv
-            company_info_type['flow_mv'] = company_one.flow_mv
-            company_info_type['area'] = company_one.area
-            company_info_type['list_date'] = company_one.list_date
-            now_date = datetime.now()
-            # 计算日期差值 距离现在上市时间
-            company_info_type['diff_days'] = (now_date - company_one.list_date_01).days
-
-            company_info_type['pe_ttm'] = company_one.pe_ttm
-            company_info_type['pb'] = company_one.pb
-            company_info_type['ROE'] = company_one.ROE
-            company_info_type['flow_mv_sp'] = company_one.flow_mv_sp
-            company_info_type['total_mv_sp'] = company_one.total_mv_sp
-            company_info_type['flow_mv_level'] = company_one.flow_mv_level
-            company_info_type['classification'] = company_one.classification
-
-            result_dict = calculate_circulation_ratio(company_one.symbol)
-            company_info_type['mv_circulation_ratio'] = result_dict['mv_circulation_ratio']
-            company_info_type['qfii_type'] = result_dict['qfii_type']
-            company_info_type['qfii_number'] = result_dict['qfii_number']
-            company_info_type['share_holder_sync_day'] = result_dict['share_holder_sync_day']
-
-            # 获取同花顺最新概念
-            company_info_type = ths_concept_common_service_api.set_ths_concept(company_one.symbol, company_info_type)
-            now_date = datetime.now()
-            str_now_date = now_date.strftime('%Y-%m-%d %H:%M:%S')
-            company_info_type['sync_date'] = str_now_date
-            fix_symbol_industry_df = company_constant_data.get_fix_symbol_industry()
-            if company_one.symbol in list(fix_symbol_industry_df['symbol']):
-                # fix sw_industry
-                company_info_type = company_constant_data.fix_symbol_industry(company_info_type, company_one.symbol)
-
-            # todo fix industry
-            company_info_type['industry'] = company_info_type['second_sw_industry']
-            company_info_type['amount'] = company_one.amount
-
-            company_info_type['kpl_plate_list_info'] = '-'
-            company_info_type['kpl_plate_name'] = '-'
-            company_info_type['kpl_most_relative_name'] = '-'
-            now_date = datetime.now()
-            str_day = now_date.strftime('%Y-%m-%d')
-            deal_days = k_line_common_service_api.get_deal_days(str_day, company_one.symbol)
-            company_info_type['deal_days'] = deal_days
-
-            # 设置年报信息
-            company_info_type = get_recent_year_income(company_one.symbol, company_info_type, exist_company_df)
-
-            try:
-                if data_frame_util.is_not_empty(kpl_real_time_quotes):
-                    kpl_real_time_quotes_one = kpl_real_time_quotes.loc[
-                        kpl_real_time_quotes['symbol'] == company_one.symbol]
-
-                    if data_frame_util.is_not_empty(kpl_real_time_quotes_one):
-                        company_info_type['kpl_plate_name'] = list(kpl_real_time_quotes_one['plate_name_list'])[0]
-                        company_info_type['kpl_most_relative_name'] = \
-                            list(kpl_real_time_quotes_one['most_relative_name'])[
-                                0]
-                    company_info_type = set_kpl_data(kpl_real_time_quotes_one, company_info_type, company_one)
-
-                if bool(1 - ("kpl_plate_name" in company_info_type.columns)) or bool(
-                        1 - ("kpl_most_relative_name" in company_info_type.columns)):
-                    company_info_type['kpl_plate_name'] = ""
-                    company_info_type['kpl_most_relative_name'] = ""
-            except BaseException as e:
-                logger.warning("设置开盘啦数据异常:{},{}", company_one.symbol, e)
-
-            company_info_type = company_constant_data.filed_sort(company_info_type)
-            mongodb_util.save_mongo(company_info_type.copy(), 'company_info_base')
-            logger.info("同步公司信息完成:{}", company_one.symbol + '-' + company_one.name)
-        except BaseException as e:
-            fail_list.append(company_one.symbol)
-            logger.error("同步公司信息发生异常:{},{}", company_one.symbol, e)
-    with result_lock:
-        # 使用锁来保护 result 变量的访问，将每页的数据添加到结果中
-        result = fail_list
-
-
 def set_kpl_data(kpl_real_time_quotes_one, company_info_type, company_one):
     if data_frame_util.is_not_empty(kpl_real_time_quotes_one):
         company_info_type['kpl_plate_name'] = list(kpl_real_time_quotes_one['plate_name_list'])[0]
@@ -517,6 +527,5 @@ if __name__ == '__main__':
     # query = {"total_operate_income": 0}
     # un_report_company_info = mongodb_util.find_query_data(db_name_constant.COMPANY_INFO, query)
     # symbol_list = list(un_report_company_info['symbol'])
+    sync_company_base_info(['920009'])
     sync_company_base_info(None)
-    sync_company_base_info(['688211', '601600', '920821', '920579', '688371', '920367'])
-
