@@ -2,7 +2,7 @@ import sys
 import os
 
 file_path = os.path.abspath(__file__)
-end = file_path.index('mns') + 16
+end = file_path.index('mns') + 17
 project_path = file_path[0:end]
 sys.path.append(project_path)
 from mns_common.db.MongodbUtil import MongodbUtil
@@ -47,7 +47,7 @@ def clean_company_info(symbol):
     company_info['company_type'] = company_info['business_nature']
 
     # 将list_date列中的所有NaN值设置为99990909
-    company_info['list_date'].fillna(20990909.0, inplace=True)
+    company_info.fillna({'list_date': 19890604}, inplace=True)
 
     # 将日期数值转换为日期时间格式
     company_info['list_date_01'] = pd.to_datetime(company_info['list_date'], format='%Y%m%d')
@@ -118,7 +118,7 @@ def save_company_info_his(company_info_df):
 # 更新新上市公司信息
 def new_company_info_update():
     east_money_stock_info = company_info_sync_api.get_east_money_stock_info()
-    new_stock = common_service_fun_api.get_new_stock(east_money_stock_info)
+    new_stock = common_service_fun_api.get_new_stock(east_money_stock_info.copy())
     for company_one in new_stock.itertuples():
         try:
             company_info_sync_api.sync_company_base_info([company_one.symbol])
