@@ -443,6 +443,9 @@ def filed_sort(company_info):
         "final_controller_name",
         "final_controller_rate",
         "mv_circulation_ratio",
+        'qfii_type',
+        'qfii_number',
+        'share_holder_sync_day',
         "flow_mv_sp",
         "total_mv_sp",
         "now_price",
@@ -478,6 +481,7 @@ def filed_sort(company_info):
         "kpl_plate_list_info",
         'operate_profit',
         'total_operate_income',
+        'operate_date_name',
         'kzz_debt_list',
         'hk_stock_code',
         'hk_stock_name',
