@@ -2,10 +2,10 @@ import sys
 import os
 
 file_path = os.path.abspath(__file__)
-end = file_path.index('mns') + 16
+end = file_path.index('mns') + 17
 project_path = file_path[0:end]
 sys.path.append(project_path)
-import mns_common.api.em.east_money_stock_api as east_money_stock_api
+import mns_common.component.em.em_stock_info_api as em_stock_info_api
 from datetime import datetime
 import mns_common.component.self_choose.black_list_service_api as black_list_service_api
 import mns_common.component.trade_date.trade_date_common_service_api as trade_date_common_service_api
@@ -48,11 +48,13 @@ def transactions_check_task():
 
     now_day_number = float(now_day_str)
 
-    real_time_quotes_now = east_money_stock_api.get_real_time_quotes_all_stocks()
-    real_time_quotes_now['list_date'] = real_time_quotes_now['list_date'].fillna(99999999)
+    real_time_quotes_now = em_stock_info_api.get_a_stock_info()
+    real_time_quotes_now['list_date'] = real_time_quotes_now['list_date'].fillna(19890604)
     real_time_quotes_now = real_time_quotes_now.loc[real_time_quotes_now['list_date'] <= now_day_number]
     real_time_quotes_now = common_service_fun_api.classify_symbol(real_time_quotes_now)
     real_time_quotes_now = common_service_fun_api.exclude_ts_symbol(real_time_quotes_now)
+    # 排除交易金额为0的
+    real_time_quotes_now = common_service_fun_api.exclude_amount_zero_stock(real_time_quotes_now)
 
     de_list_symbol = company_common_service_new_api.get_de_list_company()
 
@@ -117,7 +119,7 @@ def now_price_check(stock_one):
         return
 
     key_id = stock_one.symbol + "_" + BlackClassify.CLOSE_PRICE_RISK.level_code
-    if now_price < MIN_NOW_PRICE:
+    if MIN_NOW_PRICE > now_price > 0:
         black_list_service_api.save_black_stock(
             key_id,
             stock_one.symbol,
